@@ -1,5 +1,5 @@
 package PAR;
-$PAR::VERSION = '0.994';
+$PAR::VERSION = '1.001';
 
 use 5.006;
 use strict;
@@ -721,8 +721,12 @@ sub _extract_inc {
           mkdir($inc) if not -d $inc;
 
           for ( $zip->memberNames() ) {
-              next if m{\.\Q$dlext\E[^/]*$};
               s{^/}{};
+
+              # Skip DLLs (these will be handled by the dynaloader hook) 
+              # except for those placed in File::ShareDir directories.
+              next if (m{\.\Q$dlext\E[^/]*$} && !m{^lib/auto/share/(dist|module)/}); 
+
               my $outfile =  File::Spec->catfile($inc, $_);
               next if -e $outfile and not -w _;
               $zip->extractMember($_, "$inc/" . $_);
@@ -1232,9 +1236,9 @@ preferred.
 
 =head1 COPYRIGHT
 
-Copyright 2002-2009 by Audrey Tang
+Copyright 2002-2010 by Audrey Tang
 E<lt>cpan@audreyt.orgE<gt>.
-Copyright 2005-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>
+Copyright 2005-2010 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
